@@ -1,12 +1,11 @@
 package MooseX::Getopt::ProcessedArgv;
-{
-  $MooseX::Getopt::ProcessedArgv::VERSION = '0.59';
-}
 BEGIN {
   $MooseX::Getopt::ProcessedArgv::AUTHORITY = 'cpan:STEVAN';
 }
-use Moose;
 # ABSTRACT: MooseX::Getopt::ProcessedArgv - Class containing the results of process_argv
+$MooseX::Getopt::ProcessedArgv::VERSION = '0.64';
+use Moose;
+use namespace::autoclean;
 
 has 'argv_copy'          => (is => 'ro', isa => 'ArrayRef');
 has 'extra_argv'         => (is => 'ro', isa => 'ArrayRef');
@@ -14,8 +13,6 @@ has 'usage'              => (is => 'ro', isa => 'Maybe[Object]');
 has 'constructor_params' => (is => 'ro', isa => 'HashRef');
 has 'cli_params'         => (is => 'ro', isa => 'HashRef');
 
-no Moose;
-
 __PACKAGE__->meta->make_immutable();
 
 1;
@@ -26,15 +23,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Stevan Little Infinity Interactive, Inc
-
 =head1 NAME
 
 MooseX::Getopt::ProcessedArgv - MooseX::Getopt::ProcessedArgv - Class containing the results of process_argv
 
 =head1 VERSION
 
-version 0.59
+version 0.64
 
 =head1 SYNOPSIS
 
