@@ -1,13 +1,11 @@
 package MooseX::Getopt::Strict;
-{
-  $MooseX::Getopt::Strict::VERSION = '0.59';
-}
 BEGIN {
   $MooseX::Getopt::Strict::AUTHORITY = 'cpan:STEVAN';
 }
 # ABSTRACT: only make options for attributes with the Getopt metaclass
-
+$MooseX::Getopt::Strict::VERSION = '0.64';
 use Moose::Role;
+use namespace::autoclean;
 
 with 'MooseX::Getopt';
 
@@ -19,8 +17,6 @@ around '_compute_getopt_attrs' => sub {
     } $class->$next(@args);
 };
 
-no Moose::Role;
-
 1;
 
 __END__
@@ -29,15 +25,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Stevan Little Infinity Interactive, Inc
-
 =head1 NAME
 
 MooseX::Getopt::Strict - only make options for attributes with the Getopt metaclass
 
 =head1 VERSION
 
-version 0.59
+version 0.64
 
 =head1 DESCRIPTION
 
